@@ -4,7 +4,7 @@ package Dist::Zilla::Plugin::PodSpellingTests;
 # ABSTRACT: (DEPRECATED) The old name of the PodSpelling plugin
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '2.007000';
+our $VERSION = '2.007002';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::PodSpelling';
@@ -31,7 +31,7 @@ Dist::Zilla::Plugin::PodSpellingTests - (DEPRECATED) The old name of the PodSpel
 
 =head1 VERSION
 
-version 2.007000
+version 2.007002
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
